import React, { useCallback, useMemo } from 'react';
import {
  Text,
  View,
  StyleSheet,
  I18nManager,
  ViewStyle,
  TextStyle,
} from 'react-native';
import { useCalendarContext } from '../CalendarContext';
import Wheel from './TimePicker/Wheel';
import { CALENDAR_HEIGHT } from '../enums';
import { getParsedDate, getDate, getFormated } from '../utils';

const createNumberList = (num: number) =>
  Array.from({ length: num }, (_, index) =>
    index < 10 ? `0${index}` : `${index}`
  );

const hours = createNumberList(24);
const minutes = createNumberList(60);

const TimeSelector = () => {
  const { date, onSelectDate, theme } = useCalendarContext();
  const { hour, minute } = useMemo(() => getParsedDate(date), [date]);

  const handleChangeHour = useCallback(
    (value: number) => {
      const newDate = getDate(date).hour(value);
      onSelectDate(getFormated(newDate));
    },
    [date, onSelectDate]
  );

  const handleChangeMinute = useCallback(
    (value: number) => {
      const newDate = getDate(date).minute(value);
      onSelectDate(getFormated(newDate));
    },
    [date, onSelectDate]
  );

  const timePickerContainerStyle: ViewStyle = useMemo(
    () => ({
      ...styles.timePickerContainer,
      flexDirection: I18nManager.getConstants().isRTL ? 'row-reverse' : 'row',
    }),
    []
  );

  const timePickerTextStyle: TextStyle = useMemo(
    () => ({ ...styles.timePickerText, ...theme?.timePickerTextStyle }),
    [theme?.timePickerTextStyle]
  );

  return (
    <View style={styles.container} testID="time-selector">
      <View style={timePickerContainerStyle}>
        <View style={styles.wheelContainer}>
          <Wheel
            value={hour}
            items={hours}
            setValue={handleChangeHour}
            theme={theme}
          />
        </View>
        <Text style={timePickerTextStyle}>:</Text>
        <View style={styles.wheelContainer}>
          <Wheel
            value={minute}
            items={minutes}
            setValue={handleChangeMinute}
            theme={theme}
          />
        </View>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },
  wheelContainer: {
    flex: 1,
  },
  timePickerContainer: {
    alignItems: 'center',
    justifyContent: 'center',
    width: CALENDAR_HEIGHT / 2,
    height: CALENDAR_HEIGHT / 2,
  },
  timePickerText: {
    fontSize: 24,
    fontWeight: 'bold',
    marginHorizontal: 5,
  },
});

export default TimeSelector;
